﻿###############################################################################
#     Copy DistributionsList groups into Security groups for Office 365       #
#                                  V3.9.8.9                                   #
#                       (C)2006-2022 KoXo Developpement                       #
###############################################################################
.("%LAUNCHING_PATH%\AdminScripts\KoXo-Tools.ps1")
.("%LAUNCHING_PATH%\AdminScripts\KoXo-MSol.ps1")
###############################################################################
function exec {
    $error.Clear()
    $DistribGroups = Get-MsolGroup | Where { $_.Grouptype -eq "DistributionList" }
    ForEach ($DistribGroup in $DistribGroups) {
        $SecurityGroup = get_koxo_security_group($DistribGroup.DisplayName)
        If ([string]::IsNullOrEmpty($SecurityGroup)) {
            # Security group does not already exists
            $error.Clear()
            Write-Host "Creating"
            $Desc = $DistribGroup.DisplayName
            $SecurityGroup = New-MsolGroup -DisplayName $DistribGroup.DisplayName -Description ([string]::Format("[KOXO] {0}", $Desc))
            if ([String]::IsNullorEmpty($error[0])) {
                $S = "Successfully create security group ""$($DistribGroup.DisplayName)"", Description : ""$($Desc)"", (Id : ""$($SecurityGroup.ObjectId)"")"
                log_message "OK" $S
                Write-Host "Adding members for ""$($SecurityGroup.DisplayName)""" -ForegroundColor "Cyan"
                $MembersDistrib = Get-MsolGroupMember -GroupObjectId $DistribGroup.ObjectId
                ForEach ($MemberDistrib in $MembersDistrib) {
                    Write-Host "Adding member : $($MemberDistrib.DisplayName), Email : $($MemberDistrib.EmailAddress)" -ForegroundColor Green
                    $error.Clear()
                    $MyMember = Add-MsolGroupMember -GroupObjectId $SecurityGroup.ObjectId -GroupMemberType "User" -GroupMemberObjectId $MemberDistrib.ObjectId
                    # Gestion erreurs ....
   
                    if ([String]::IsNullorEmpty($error[0])) {
                        $S = "Successfully add member ""$($MemberDistrib.DisplayName)"", Email : ""$($MemberDistrib.EmailAddress)"" to security group ""$($SecurityGroup.DisplayName)"""
                        log_message "OK" $S
                    }
                    else {
                        $global:errors_count++
                        $S = "Adding member ""$($MemberDistrib.DisplayName)"", Email : ""$($MemberDistrib.EmailAddress)"" to security group ""$($SecurityGroup.DisplayName)"". Error = $($error[0])"
                        log_message "ERROR" $S
                    }
                }
            }
            else {
                $global:errors_count++
                $S = "Creating security group ""$($DistribGroup.DisplayName)"", Description : ""$($Desc)"". Error = $($error[0])"
                log_message "ERROR" $S
            }
        }
        else {
            # Security group already exists
            Write-Host "Adding/Removing members for ""$($SecurityGroup.DisplayName)""" -ForegroundColor "Cyan"
            $MembersSecu = Get-MsolGroupMember -GroupObjectId $SecurityGroup.ObjectId
            $MembersDistrib = Get-MsolGroupMember -GroupObjectId $DistribGroup.ObjectId
            $MembersToAdd = New-Object System.Collections.ArrayList
            $MembersToRemove = New-Object System.Collections.ArrayList
            ForEach ($MemberDistrib in $MembersDistrib) {
                $index = $MembersToAdd.Add($MemberDistrib.EmailAddress)
            }
            ForEach ($MemberSecu in $MembersSecu) {
                $index = $MembersToRemove.Add($MemberSecu.EmailAddress)
            }
            ForEach ($MyMember in $MembersDistrib) {
                $index = $MembersToRemove.IndexOf($MyMember.EmailAddress)
                if ($index -gt -1) { $MembersToAdd.Remove($MyMember.EmailAddress) }
            }
            ForEach ($MyMember in $MembersSecu) {
                $index = $MembersToRemove.IndexOf($MyMember.EmailAddress)
                if ($index -gt -1) { $MembersToRemove.Remove($MyMember.EmailAddress) }
            }
            ForEach ($Email in $MembersToRemove) {
                $Member = Get-MsolUser -UserPrincipalName $Email
                Write-Host "Removing member : $($Member.DisplayName), Email : $($Member.UserPrincipalName)" -ForegroundColor Yellow
                $error.Clear()
                Remove-MsolGroupMember -GroupObjectId $SecurityGroup.ObjectId -GroupMemberObjectId $Member.ObjectId
                # Gestion erreurs ....
                if ([String]::IsNullorEmpty($error[0])) {
                    $S = "Successfully remove member ""$($Member.DisplayName)"", Email : ""$($Member.UserPrincipalName)"" from security group ""$($SecurityGroup.DisplayName)"""
                    log_message "OK" $S
                }
                else {
                    $global:errors_count++
                    $S = "Removing member ""$($Member.DisplayName)"", Email : ""$($Member.UserPrincipalName)"" from security group ""$($SecurityGroup.DisplayName)"". Error = $($error[0])"
                    log_message "ERROR" $S
                }
            }
            ForEach ($Email in $MembersToAdd) {
                $Member = Get-MsolUser -UserPrincipalName $Email
                Write-Host "Adding member : $($Member.DisplayName), Email : $($Member.UserPrincipalName)" -ForegroundColor Yellow
                $error.Clear()
                Add-MsolGroupMember -GroupObjectId $SecurityGroup.ObjectId -GroupMemberObjectId $Member.ObjectId
                # Gestion erreurs ....
                if ([String]::IsNullorEmpty($error[0])) {
                    $S = "Successfully add member ""$($Member.DisplayName)"", Email : ""$($Member.UserPrincipalName)"" from security group ""$($SecurityGroup.DisplayName)"""
                    log_message "OK" $S
                }
                else {
                    $global:errors_count++
                    $S = "Adding member ""$($Member.DisplayName)"", Email : ""$($Member.UserPrincipalName)"" from security group ""$($SecurityGroup.DisplayName)"". Error = $($error[0])"
                    log_message "ERROR" $S
                }
            }
        }
    }
}
###############################################################################
#                                    Main                                     #
###############################################################################
$Copyright = "(C)2006-2022 KoXo Developpement"
$Version = "V3.9.8.9"
$Title = "Copy DistributionsList groups into Security groups for Office 365 $($Version)", "$($Copyright)"
# Office 365 params
$Office365LoginName = "%OFFICE365_ADMIN%"
$Office365LoginPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%OFFICE365_BASE64_PASSWORD%"))
# Proxy parameters
$ProxyEnabled = $#BOOL{%PROXY_ENABLED%}
$ProxyUser = "%PROXY_USER%"     
$ProxyPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%PROXY_BASE64_PASSWORD%"))
$ProxyUrl = "%PROXY_ADDRESS%"
$ProxyPort = %PROXY_PORT%
# Log filename
$LogFile = $MyInvocation.MyCommand.Definition 
$LogFile = $LogFile -replace(".ps1",".log")
#
$global:total_errors_count = 0
#
banner $Title
check_version
if (import_modules MSOnline) {
    set_proxy $ProxyEnabled $ProxyUrl $ProxyPort $ProxyUser $ProxyPassword
    if ((connect_msol $Office365LoginName $Office365LoginPassword) -eq $true) {
        $Groups = Get-MsolGroup | Where { $_.Grouptype -eq "DistributionList" }
        if ($Groups -ne $null) {
            write-host "Distribution groups are : " -foregroundcolor "white"
            ForEach ($Group in $Groups) {
                write-host -nonewline """$($Group.EmailAddress)"" "
            }
            write-host        
            write-host -nonewline "Copy all these groups ? Enter YES to continue : " -foregroundcolor "magenta"
            $ret = read-host
            $ret = $ret.ToLower()
            if ($ret -eq "yes") {  
                exec
            }
        }  	
    }
    else {
        write-host -nonewline "There are no distribution groups ! Press any key to continue : " -foregroundcolor "magenta"
        read-host
    }
    else {
        $global:total_errors_count++
        $S = "Unable to connect to MSOnline !"
        Write-Host $S -Foregroundcolor "Red"
        Log_Message "ERROR" $S
    }
}
else {
    $global:total_errors_count++
    $S = "MSOline Powershell module cannot be loaded !"
    Write-Host $S -Foregroundcolor "Red"
    Log_Message "ERROR" $S
}
log_total_errors_count