﻿###############################################################################
#                    Primary group informations for Office 365                #
#                                  V3.9.8.9                                   #
#                       (C)2006-2022 KoXo Developpement                       #
###############################################################################
.("%LAUNCHING_PATH%\AdminScripts\KoXo-Tools.ps1")
.("%LAUNCHING_PATH%\AdminScripts\KoXo-ExchangeOnline.ps1")
###############################################################################
function exec {
    Param([string] $Group)
    $crlf = "`r`n"
        if (distribution_group_exists($Group)) {
            write-host "Distribution group : $($Group)"
            $Log.Text = $Log.Text + "------ Get-Group ""$($Group)"" ------"
            $GrpInfo = group_info($Group)
            $Info = $GrpInfo | fl | Out-String
            $Members = $GrpInfo.Members | fl | Out-String
            $Log.Text = $Log.Text + $Info
            $Log.Text = $Log.Text + "------ Members ""$($Group)"" ------" + $crlf
            $Log.Text = $Log.Text + $Members + $crlf + $crlf
            $Log.Text = $Log.Text + "------ Get-DistributionGroup ""$($Group)"" ------"
            $Info = distributiongroup_info($Group) | fl | Out-String
            $Log.Text = $Log.Text + $Info
            $Log.Text = $Log.Text + "------ Get-DistributionGroupMember ""$($Group)"" ------" + $crlf 
            $Info = distributiongroupmember_info($Group) | Out-String
            $Log.Text = $Log.Text + $Info + $crlf
        }
        else {
        $Log.Text = $Log.Text + "------------------------------------------------------------" + $crlf
        $Log.Text = $Log.Text + "Distribution group ""$($Group)"" does not exists !" + $crlf
        $Log.Text = $Log.Text + "------------------------------------------------------------" + $crlf
        }
    if (![string]::IsNullOrEmpty($Group)) {
        if (dynamic_group_exists($Group)) {
            write-host "Dynamic distribution group : $($Group)"
            $Log.Text = $Log.Text + "------ Get-DynamicDistributionGroup ""$($Group)"" ------" + $crlf
            $Info = dynamicgroup_info($Group) | fl | Out-String
            $Log.Text = $Log.Text + $Info
        }
        else {
        $Log.Text = $Log.Text + "------------------------------------------------------------" + $crlf
        $Log.Text = $Log.Text + "Dynamic distribution group ""$($Group)"" does not exists !" + $crlf
        $Log.Text = $Log.Text + "------------------------------------------------------------" + $crlf
        }
    }
}
###############################################################################
#                                    Main                                     #
###############################################################################
$Copyright = "(C)2006-2022 KoXo Developpement"
$Version = "V3.9.8.9"
$Title = "Primary group informations for Office 365 $($Version)", "$($Copyright)"
# Office 365 params
$Office365LoginName = "%OFFICE365_ADMIN%"
$Office365LoginPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%OFFICE365_BASE64_PASSWORD%"))
# Proxy parameters
$ProxyEnabled = $#BOOL{%PROXY_ENABLED%}
$ProxyUser = "%PROXY_USER%"     
$ProxyPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%PROXY_BASE64_PASSWORD%"))
$ProxyUrl = "%PROXY_ADDRESS%"
$ProxyPort = %PROXY_PORT%
# Log filename
$LogFile = $MyInvocation.MyCommand.Definition 
$LogFile = $LogFile -replace(".ps1",".log")
#
$global:total_errors_count = 0
#
banner $Title
check_version
if (import_modules "MSOnline,ExchangeOnlineManagement") {
    set_proxy $ProxyEnabled $ProxyUrl $ProxyPort $ProxyUser $ProxyPassword
        if ((connect_exo $Office365LoginName $Office365LoginPassword) -eq $true) {
            [void][Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms")
            [void][Reflection.Assembly]::LoadWithPartialName("System.Drawing")
            $panel1 = new-object System.Windows.Forms.Panel
            $buttonClose = new-object System.Windows.Forms.Button
            $groupBox1 = new-object System.Windows.Forms.GroupBox
            $Log = new-object System.Windows.Forms.TextBox
            #
            # panel1
            #
            $panel1.Anchor = [System.Windows.Forms.AnchorStyles]"Bottom,Left,Right"
            $panel1.BackColor = [System.Drawing.Color]::FromArgb(30, 139, 225)
            $panel1.Controls.Add($buttonClose)
            $panel1.Location = new-object System.Drawing.Point(0, 402)
            $panel1.Name = "panel1"
            $panel1.Size = new-object System.Drawing.Size(673, 35)
            $panel1.TabIndex = 0
            #
            # buttonClose
            #
            $buttonClose.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Right"
            $buttonClose.Location = new-object System.Drawing.Point(579, 5)
            $buttonClose.Name = "buttonClose"
            $buttonClose.Size = new-object System.Drawing.Size(89, 25)
            $buttonClose.TabIndex = 0
            $buttonClose.Text = "&Close"
            $buttonClose.UseVisualStyleBackColor = $true
            function OnClick_buttonClose($Sender, $e) { $MyForm.Close() }
            $buttonClose.Add_Click( { OnClick_buttonClose $buttonClose $EventArgs } )
            #
            # groupBox1
            #
            $groupBox1.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Left,Right"
            $groupBox1.BackColor = [System.Drawing.Color]::FromArgb(30, 139, 225)
            $groupBox1.Controls.Add($Log)
            $groupBox1.Location = new-object System.Drawing.Point(0, 0)
            $groupBox1.Name = "groupBox1"
            $groupBox1.Size = new-object System.Drawing.Size(672, 402)
            $groupBox1.TabIndex = 2
            $groupBox1.TabStop = $false
            $groupBox1.Text = " Informations "
            #
            # Log
            #
            $Log.AcceptsReturn = $true
            $Log.AcceptsTab = $true
            $Log.Anchor = [System.Windows.Forms.AnchorStyles]"Top,Bottom,Left,Right"
            $Log.BackColor = [System.Drawing.Color]::FromArgb(151, 192, 234)
            $Log.Cursor = [System.Windows.Forms.Cursors]::Default
            $Log.Font = new-object System.Drawing.Font("Courier New", 10, [System.Drawing.FontStyle]::Bold)
            $Log.Location = new-object System.Drawing.Point(6, 16)
            $Log.Multiline = $true
            $Log.Name = "Log"
            $Log.ScrollBars = [System.Windows.Forms.ScrollBars]::Both
            $Log.Size = new-object System.Drawing.Size(660, 382)
            $Log.TabIndex = 0
            $Log.WordWrap = $false
            #
            $MyForm = new-object System.Windows.Forms.form
            #
            $MyForm.AutoSize = $true
            $MyForm.ClientSize = new-object System.Drawing.Size(672, 440)
            $MyForm.Controls.Add($groupBox1)
            $MyForm.Controls.Add($panel1)
            $MyForm.Name = "MyForm"
            $MyForm.StartPosition = [System.Windows.Forms.FormStartPosition]::CenterScreen
            $MyForm.Text = "$($Copyright) | Office 365 Powershell Log"
            #
            ### BEGIN_REPETITION ###
            $PrimaryGroup = "#LOWER{#REMOVE_SPACE{%PRIMARY_GROUP%}}"
            exec $PrimaryGroup
            ### END_REPETITION ###
            #
            $MyForm.Topmost = $False
            $MyForm.Add_Shown({ $MyForm.Activate() })
            [void] $MyForm.ShowDialog()
            $MyForm.Dispose()
            # close
			Disconnect-ExchangeOnline -Confirm:$false
        }
        else {
            $global:total_errors_count++
            $S = "Unable to connect to Exchange Online !"
            Write-Host $S -Foregroundcolor "Red"
            Log_Message "ERROR" $S                
        }
}
else {
    $global:total_errors_count++
    $S = "Cannot load all modules !"
    Write-Host $S -Foregroundcolor "Red"
    Log_Message "ERROR" $S        
}
log_total_errors_count