﻿###############################################################################
#                 Adding license pack for users for Office 365                #
#                                  V3.9.8.9                                   #
#                       (C)2006-2022 KoXo Developpement                       #
###############################################################################
.("%LAUNCHING_PATH%\AdminScripts\KoXo-Tools.ps1")
.("%LAUNCHING_PATH%\AdminScripts\KoXo-MSol.ps1")
.("%LAUNCHING_PATH%\AdminScripts\KoXo-ExchangeOnline.ps1")
###############################################################################
function exec {
    Param($UserDisplayName, $UserEmail, $Prefix, $LicensePacks, $DisabledPlans, $UsageLocation, $StrongPasswordRequired, $PasswordNeverExpires)
    $UserDisplayName = $UserDisplayName.Trim()
    log_message "OFFICE365" "$($UserDisplayName) ($($UserEmail))"
    if (user_exists($UserEmail)) {
        display_user	$UserDisplayName $UserEmail
        if (msol_user_exists($UserEmail)) {
            If (user_has_at_least_one_license $UserEmail) {
                $global:warnings_count++
                $S = "MSol User ""$($UserEmail)"" already has at least one license pack"
                write-host $S -foregroundcolor "yellow"
                log_message "WARNING" $S
                display_user_licenses $UserDisplayName $UserEmail
            }
            $LicensePackList = $LicensePacks.Split(",", [System.StringSplitOptions]::RemoveEmptyEntries)
            ForEach ($LicensePack in $LicensePackList) {
                If (![String]::IsNullOrEmpty($LicensePack)) {
                    $LicensePack = $Prefix + ':' + $LicensePack                
                    set_location_user $UserDisplayName $UserEmail $UsageLocation
                    If (!(user_has_license $UserEmail $LicensePack)) {
                        add_license_pack_user $UserDisplayName $UserEmail $LicensePack
                    }               
                    If (user_has_license $UserEmail $LicensePack) {
                        disable_user_plans $UserDisplayName $UserEmail $LicensePack $DisabledPlans
                    }
                    check_user_licenses_and_plans $UserDisplayName $UserEmail
                }   
            }      
            set_password_options $UserDisplayName $UserEmail $StrongPasswordRequired $PasswordNeverExpires
        }
        else {
            $global:errors_count++
            $S = "MSol User ""$($UserEmail)"" does not exists"
            write-host $S -foregroundcolor "red"
            log_message "ERROR" $S
        }
        set_regional_configuration $UserDisplayName $UserEmail $Language $TimeZone
        Set-MsolUser -UserPrincipalName $UserEmail -PreferredLanguage $Language -UsageLocation $Language.Substring(0, 2).ToUpper() -ErrorAction SilentlyContinue
    }
    else {
        $global:errors_count++
        $S = "User ""$($UserEmail)"" does not exists"
        write-host $S -foregroundcolor "red"
        log_message "ERROR" $S
    }
    log_errors_count($UserEmail)   
    log_warnings_count($UserEmail)   
    $global:total_errors_count = $global:total_errors_count + $global:errors_count
    $global:total_warnings_count = $global:total_warnings_count + $global:warnings_count
}
###############################################################################
#                                    Main                                     #
###############################################################################
$Copyright = "(C)2006-2022 KoXo Developpement"
$Version = "V3.9.8.9"
$Title = "Adding license pack for users for Office 365 $($Version)", "Disable specified plans", "Configurating regional options", "Configurating Office 365 password options", "$($Copyright)"
# Office 365 params
$Office365LoginName = "%OFFICE365_ADMIN%"
$Office365LoginPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%OFFICE365_BASE64_PASSWORD%"))
# Proxy parameters
$ProxyEnabled = $#BOOL{%PROXY_ENABLED%}
$ProxyUser = "%PROXY_USER%"     
$ProxyPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%PROXY_BASE64_PASSWORD%"))
$ProxyUrl = "%PROXY_ADDRESS%"
$ProxyPort = %PROXY_PORT%
# Exchange Online
$Language = "%OFFICE365_LANGUAGE%"
$TimeZone = "%OFFICE365_TIMEZONE%"
# License pack parameters
If ($Language.IndexOf("-") -gt 0)
   {
   $UsageLocation=$Language.Substring(0,2).ToUpper()
   }
   else
   {
   $UsageLocation=$Language.ToUpper()
   }
# Log filename
$LogFile = $MyInvocation.MyCommand.Definition 
$LogFile = $LogFile -replace(".ps1",".log")
#
$global:total_errors_count = 0
$global:total_warnings_count = 0
#
banner $Title
check_version
if (import_modules "MSOnline,ExchangeOnlineManagement") {
    set_proxy $ProxyEnabled $ProxyUrl $ProxyPort $ProxyUser $ProxyPassword
    if ((connect_msol $Office365LoginName $Office365LoginPassword) -eq $true) {
        if ((connect_exo $Office365LoginName $Office365LoginPassword) -eq $true) {
            $Prefix = license_pack_domain  
            $StrongPasswordRequired = $#BOOL{%OFFICE365_STRONG_PASSWORD_REQUIRED%}
            $PasswordNeverExpires = $#BOOL{%OFFICE365_PASSWORD_NEVER_EXPIRES%}
            ### BEGIN_REPETITION ###
            $global:errors_count = 0
            $global:warnings_count = 0
            $UserDisplayName = "%USER_TITLE% %USER_FIRST_NAME% %USER_LAST_NAME%"
            $UserEmail = "%USER_EMAIL%"
            $LicensePack = "%OFFICE365_LICENSE_PACK%"
            $DisabledPlans = "%OFFICE365_DISABLED_PLANS%"
            exec $UserDisplayName $UserEmail $Prefix $LicensePack $DisabledPlans $UsageLocation $StrongPasswordRequired $PasswordNeverExpires
            ### END_REPETITION ### 
            Disconnect-ExchangeOnline -Confirm:$false			
        }
        else {
            $global:total_errors_count++
            $S = "Unable to connect to Exchange Online !"
            Write-Host $S -Foregroundcolor "Red"
            Log_Message "ERROR" $S                
        }
    }
    else {
        $global:total_errors_count++
        $S = "Unable to connect to MSonline !"
        Write-Host $S -Foregroundcolor "Red"
        Log_Message "ERROR" $S        
    }
}
else {
    $global:total_errors_count++
    $S = "Cannot load all modules !"
    Write-Host $S -Foregroundcolor "Red"
    Log_Message "ERROR" $S        
}
log_total_errors_count
log_total_warnings_count