﻿###############################################################################
#                   Delete license for users for Office 365                   #
#                                  V3.9.8.9                                   #
#                       (C)2006-2022 KoXo Developpement                       #
###############################################################################
.("%LAUNCHING_PATH%\AdminScripts\KoXo-Tools.ps1")
.("%LAUNCHING_PATH%\AdminScripts\KoXo-MSol.ps1")
###############################################################################
function exec {
    Param($UserDisplayName, $UserEmail, $Prefix, $LicensePacks)
    $UserDisplayName = $UserDisplayName.Trim()
    log_message "OFFICE365" "$($UserDisplayName) ($($UserEmail))"
    display_user $UserDisplayName $UserEmail
    if (msol_user_exists($UserEmail)) {
        $LicensePackList = $LicensePacks.Split(",")
        ForEach ($LicensePack in $LicensePackList) {
            if (![String]::IsNullOrEmpty($LicensePack)) {
                $LicensePack = $Prefix + ':' + $LicensePack
				if (user_has_license $UserEmail $LicensePack) {                    
                    remove_user_license_pack $UserDisplayName $UserEmail $LicensePack
                }
                else {
                    $global:errors_count++
                    $S = "MSol User ""$($UserEmail)"" has no license pack : " + $LicensePack
                    write-host $S -foregroundcolor "red"
                    log_message "ERROR" $S
                    display_licenses $UserDisplayName $UserEmail
                }
            }
        }      
    }
    else {
        $global:errors_count++
        $S = "MSol User ""$($UserEmail)"" does not exists"
        write-host $S -foregroundcolor "red"
        log_message "ERROR" $S
    }
    log_errors_count($UserEmail)   
    $global:total_errors_count = $global:total_errors_count + $global:errors_count
}
###############################################################################
#                                    Main                                     #
###############################################################################
$Copyright = "(C)2006-2022 KoXo Developpement"
$Version = "V3.9.8.9"
$Title = "Delete license for users for Office 365 $($Version)", "$($Copyright)"
# Office 365 params
$Office365LoginName = "%OFFICE365_ADMIN%"
$Office365LoginPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%OFFICE365_BASE64_PASSWORD%"))
# Proxy parameters
$ProxyEnabled = $#BOOL{%PROXY_ENABLED%}
$ProxyUser = "%PROXY_USER%"     
$ProxyPassword = [System.Text.Encoding]::ASCII.GetString([System.Convert]::FromBase64String("%PROXY_BASE64_PASSWORD%"))
$ProxyUrl = "%PROXY_ADDRESS%"
$ProxyPort = %PROXY_PORT%
# License pack parameters
$UsageLocation = "FR"
# Log filename
$LogFile = $MyInvocation.MyCommand.Definition 
$LogFile = $LogFile -replace(".ps1",".log")
#
$global:total_errors_count = 0
#
banner $Title
check_version
if (import_modules MSOnline) {
    set_proxy $ProxyEnabled $ProxyUrl $ProxyPort $ProxyUser $ProxyPassword
    if ((connect_msol $Office365LoginName $Office365LoginPassword) -eq $true) {
        $Prefix = license_pack_domain  
        ### BEGIN_REPETITION ###
        $global:errors_count = 0
        $LicensePacks = "%OFFICE365_LICENSE_PACK_TO_REMOVE%"
        $UserDisplayName = "%USER_TITLE% %USER_FIRST_NAME% %USER_LAST_NAME%"
        $UserEmail = "%USER_EMAIL%"
        exec $UserDisplayName $UserEmail $Prefix $LicensePacks
        ### END_REPETITION ###      
    }
    else {
        $global:total_errors_count++
        $S = "Unable to connect to MSonline !"
        Write-Host $S -Foregroundcolor "Red"
        Log_Message "ERROR" $S
    }
}
else {
    $global:total_errors_count++
    $S = "MSOnline Powershell module cannot be loaded !"
    Write-Host $S -Foregroundcolor "Red"
    Log_Message "ERROR" $S
}
log_total_errors_count